#pragma once

#include "DataGlove.h"
class Project
{
public:
	Project(void);
	~Project(void);
	
	int AddDataGlove(const char *label, int comport, int type);
	bool RemoveGlove(int gloveid);
	DataGlove *GetDataGlove(int id);
	int SetGloveBufferSize(int size_finger, int size_acc, int gloveid);
	int SaveProject(void);
	int LoadProject(void);
	int GetNumDataGlove(void);
	void CloseProject(void);
	
	int StartSampling(int gloveid);
	int StopSampling(int gloveid);
};
