// TestDllMFCDlg.cpp : file di implementazione
//

#include "stdafx.h"
#include "TestDllMFC.h"
#include "TestDllMFCDlg.h"
#include ".\testdllmfcdlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif


// finestra di dialogo CAboutDlg utilizzata per visualizzare le informazioni sull'applicazione.

class CAboutDlg : public CDialog
{
public:
	CAboutDlg();

// Dati della finestra di dialogo
	enum { IDD = IDD_ABOUTBOX };

	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // supporto DDX/DDV

// Implementazione
protected:
	DECLARE_MESSAGE_MAP()
};

CAboutDlg::CAboutDlg() : CDialog(CAboutDlg::IDD)
{
}

void CAboutDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
}

BEGIN_MESSAGE_MAP(CAboutDlg, CDialog)
END_MESSAGE_MAP()


// finestra di dialogo CTestDllMFCDlg



CTestDllMFCDlg::CTestDllMFCDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CTestDllMFCDlg::IDD, pParent)
	, GloveValue(_T(""))
	, Rotation(_T(""))
	, Finger(_T(""))
{
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CTestDllMFCDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	DDX_Text(pDX, GLOVEVALUE, GloveValue);
	DDX_Text(pDX, ROTATION, Rotation);
	DDX_Text(pDX, FINGER, Finger);
}

BEGIN_MESSAGE_MAP(CTestDllMFCDlg, CDialog)
	ON_WM_SYSCOMMAND()
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	//}}AFX_MSG_MAP
	ON_WM_TIMER()
END_MESSAGE_MAP()


// gestori di messaggi di CTestDllMFCDlg

BOOL CTestDllMFCDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Aggiungere la voce di menu "Informazioni su..." al menu di sistema.

	// IDM_ABOUTBOX deve trovarsi tra i comandi di sistema.
	ASSERT((IDM_ABOUTBOX & 0xFFF0) == IDM_ABOUTBOX);
	ASSERT(IDM_ABOUTBOX < 0xF000);

	CMenu* pSysMenu = GetSystemMenu(FALSE);
	if (pSysMenu != NULL)
	{
		CString strAboutMenu;
		strAboutMenu.LoadString(IDS_ABOUTBOX);
		if (!strAboutMenu.IsEmpty())
		{
			pSysMenu->AppendMenu(MF_SEPARATOR);
			pSysMenu->AppendMenu(MF_STRING, IDM_ABOUTBOX, strAboutMenu);
		}
	}

	// Impostare l'icona per questa finestra di dialogo. Il framework non esegue questa operazione automaticamente
	//  se la finestra principale dell'applicazione non è una finestra di dialogo.
	SetIcon(m_hIcon, TRUE);			// Impostare icona grande.
	SetIcon(m_hIcon, FALSE);		// Impostare icona piccola.

	// TODO: aggiungere qui inizializzazione aggiuntiva.
	prj = new Project();
	prj->LoadProject();
	id = prj->AddDataGlove("test",22,0);
	prj->SetGloveBufferSize(20,20,id);
	prj->StartSampling(id);
	prj->SaveProject();

	SetTimer(TIMER,50,NULL);
	return TRUE;  // restituisce TRUE a meno che non venga impostato lo stato attivo su un controllo.
}

void CTestDllMFCDlg::OnSysCommand(UINT nID, LPARAM lParam)
{
	if ((nID & 0xFFF0) == IDM_ABOUTBOX)
	{
		CAboutDlg dlgAbout;
		dlgAbout.DoModal();
	}
	else
	{
		CDialog::OnSysCommand(nID, lParam);
	}
}

// Se si aggiunge alla finestra di dialogo un pulsante di riduzione a icona, per trascinare l'icona sarà necessario
//  il codice sottostante. Per le applicazioni MFC che utilizzano il modello documento/vista,
//  questa operazione viene eseguita automaticamente dal framework.

void CTestDllMFCDlg::OnPaint() 
{
	if (IsIconic())
	{
		CPaintDC dc(this); // contesto di periferica per il disegno

		SendMessage(WM_ICONERASEBKGND, reinterpret_cast<WPARAM>(dc.GetSafeHdc()), 0);

		// Centrare l'icona nel rettangolo client.
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Disegnare l'icona
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialog::OnPaint();
	}
}

// Il sistema chiama questa funzione per ottenere la visualizzazione del cursore durante il trascinamento
//  della finestra ridotta a icona.
HCURSOR CTestDllMFCDlg::OnQueryDragIcon()
{
	return static_cast<HCURSOR>(m_hIcon);
}

void CTestDllMFCDlg::OnTimer(UINT nIDEvent)
{
	// TODO: Add your message handler code here and/or call default
	DataGlove *gl = prj->GetDataGlove(id);
	if (gl)
	{
		GloveValue.Format("Ax:%2.1f Ay:%2.1f Az:%2.1f",gl->az,gl->ay,gl->az);
		Rotation.Format("Roll:%2.2f Pitch:%2.2f",gl->roll,gl->pitch);
		Finger.Format("F1:%3.2f F2:%3.2F F3:%3.2f F4:%3.2f F5:%3.2f",
			gl->f[0],gl->f[1],gl->f[2],gl->f[3],gl->f[4],gl->f[5]);
		UpdateData(false);
	}

	CDialog::OnTimer(nIDEvent);
}
